#! /usr/bin/perl -w

########
## Probe description database
########

package wlcgprobes;

require Exporter;
@ISA = qw(Exporter);
@EXPORT_OK = qw($WLCG_NODETYPE $WLCG_SERVICE);

# table ServiceNodeType
$WLCG_NODETYPE->{BDII}->{services} = ["BDII"];
$WLCG_NODETYPE->{'Site-BDII'}->{services} = ["BDII"];
$WLCG_NODETYPE->{RB}->{services} = ["ResourceBroker","gsiftp","MDS-GIIS","CAdistribution"];
$WLCG_NODETYPE->{CE}->{services} = ["globus-GRAM","gsiftp","MDS-GIIS","CAdistribution"];
$WLCG_NODETYPE->{SE}->{services} = ["gsiftp","MDS-GIIS","CAdistribution"];
$WLCG_NODETYPE->{SRM}->{services} = ["SRM"];
$WLCG_NODETYPE->{DPM}->{services} = ["DPNS","BDII"];
$WLCG_NODETYPE->{MON}->{services} = ["it.infn.GridICE"];
$WLCG_NODETYPE->{PROX}->{services} = ["MyProxy","MDS-GIIS"];
$WLCG_NODETYPE->{LFC}->{services} = ["glite-LFC","MDS-GIIS"];
$WLCG_NODETYPE->{WMS}->{services} = ["gsiftp","org.glite.wms.NetworkServer","org.glite.wms.WMProxy","CAdistribution"];
$WLCG_NODETYPE->{'gLite-CE'}->{services} = ["globus-GRAM","gsiftp","MDS-GIIS","CAdistribution"];

my $SERVICE_TEMPL;

$SERVICE_TEMPL->{15}->{interval} = 15;
$SERVICE_TEMPL->{15}->{timeout} = 120;
$SERVICE_TEMPL->{15}->{retryInterval} = 5;

$SERVICE_TEMPL->{60}->{interval} = 60;
$SERVICE_TEMPL->{60}->{timeout} = 600;
$SERVICE_TEMPL->{60}->{retryInterval} = 15;

$SERVICE_TEMPL->{1440}->{interval} = 1440;
$SERVICE_TEMPL->{1440}->{timeout} = 120;
$SERVICE_TEMPL->{1440}->{retryInterval} = 60;


# GridFTP service
$WLCG_SERVICE->{gsiftp}->{metrics}->{'hr.srce.GridFTP-Transfer'}->{config} = {%{$SERVICE_TEMPL->{60}}};
$WLCG_SERVICE->{gsiftp}->{metrics}->{'hr.srce.GridFTP-Transfer'}->{probe} = 'hr.srce/GridFTP-probe';
$WLCG_SERVICE->{gsiftp}->{metrics}->{'hr.srce.GridFTP-Transfer'}->{dependency} = ["hr.srce.GridProxy-Valid","org.nagios.GridFTP-Check"];
$WLCG_SERVICE->{gsiftp}->{metrics}->{'hr.srce.GridFTP-Transfer'}->{attribute}->{SE_PATH} = "--path";
$WLCG_SERVICE->{gsiftp}->{metrics}->{'hr.srce.GridFTP-Transfer'}->{attribute}->{PROXY_PATH} = "-x";
$WLCG_SERVICE->{gsiftp}->{metrics}->{'hr.srce.GridFTP-Transfer'}->{attribute}->{VONAME} = "-v";
# bypass voms proxy cert (GGUS #20558)
#$WLCG_SERVICE->{GridFTP}->{metrics}->{Transfer}->{gridproxy} = 1;

# GRAM service
$WLCG_SERVICE->{'globus-GRAM'}->{metrics}->{'hr.srce.GRAM-Auth'}->{config} = {%{$SERVICE_TEMPL->{15}}}; 
$WLCG_SERVICE->{'globus-GRAM'}->{metrics}->{'hr.srce.GRAM-Auth'}->{probe} = 'hr.srce/GRAM-probe';
$WLCG_SERVICE->{'globus-GRAM'}->{metrics}->{'hr.srce.GRAM-Auth'}->{dependency} = ["hr.srce.GRAM-CertLifetime","hr.srce.GridProxy-Valid"];
$WLCG_SERVICE->{'globus-GRAM'}->{metrics}->{'hr.srce.GRAM-Auth'}->{attribute}->{PROXY_PATH} = "-x";
$WLCG_SERVICE->{'globus-GRAM'}->{metrics}->{'hr.srce.GRAM-Auth'}->{attribute}->{VONAME} = "-v";

$WLCG_SERVICE->{'globus-GRAM'}->{metrics}->{'hr.srce.GRAM-Command'}->{config} = {%{$SERVICE_TEMPL->{60}}};
$WLCG_SERVICE->{'globus-GRAM'}->{metrics}->{'hr.srce.GRAM-Command'}->{probe} = 'hr.srce/GRAM-probe';
$WLCG_SERVICE->{'globus-GRAM'}->{metrics}->{'hr.srce.GRAM-Command'}->{dependency} = ["hr.srce.GRAM-Auth","hr.srce.GridProxy-Valid"];
$WLCG_SERVICE->{'globus-GRAM'}->{metrics}->{'hr.srce.GRAM-Command'}->{attribute}->{PROXY_PATH} = "-x";
$WLCG_SERVICE->{'globus-GRAM'}->{metrics}->{'hr.srce.GRAM-Command'}->{attribute}->{VONAME} = "-v";
# bypass voms proxy cert (GGUS #20558)
#$WLCG_SERVICE->{GRAM}->{metrics}->{Command}->{gridproxy} = 1;

$WLCG_SERVICE->{'globus-GRAM'}->{metrics}->{'hr.srce.GRAM-CertLifetime'}->{config} = {%{$SERVICE_TEMPL->{1440}}};
$WLCG_SERVICE->{'globus-GRAM'}->{metrics}->{'hr.srce.GRAM-CertLifetime'}->{probe} = 'hr.srce/GRAM-probe';

# MyProxy
$WLCG_SERVICE->{MyProxy}->{metrics}->{'hr.srce.MyProxy-Store'}->{config} = {%{$SERVICE_TEMPL->{15}}};
$WLCG_SERVICE->{MyProxy}->{metrics}->{'hr.srce.MyProxy-Store'}->{probe} = 'hr.srce/MyProxy-probe';
$WLCG_SERVICE->{MyProxy}->{metrics}->{'hr.srce.MyProxy-Store'}->{dependency} = ["hr.srce.MyProxy-CertLifetime","hr.srce.GridProxy-Valid"];
$WLCG_SERVICE->{MyProxy}->{metrics}->{'hr.srce.MyProxy-Store'}->{attribute}->{PROXY_PATH} = "-x";
$WLCG_SERVICE->{MyProxy}->{metrics}->{'hr.srce.MyProxy-Store'}->{attribute}->{VONAME} = "-v";

$WLCG_SERVICE->{MyProxy}->{metrics}->{'hr.srce.MyProxy-CertLifetime'}->{config} = {%{$SERVICE_TEMPL->{1440}}};
$WLCG_SERVICE->{MyProxy}->{metrics}->{'hr.srce.MyProxy-CertLifetime'}->{probe} = 'hr.srce/MyProxy-probe';

# SRM
$WLCG_SERVICE->{SRM}->{metrics}->{'hr.srce.SRM-Ping'}->{config} = {%{$SERVICE_TEMPL->{15}}};
$WLCG_SERVICE->{SRM}->{metrics}->{'hr.srce.SRM-Ping'}->{probe} = 'hr.srce/SRM-probe';
$WLCG_SERVICE->{SRM}->{metrics}->{'hr.srce.SRM-Ping'}->{dependency} = ["hr.srce.SRM-CertLifetime","hr.srce.GridProxy-Valid"];
$WLCG_SERVICE->{SRM}->{metrics}->{'hr.srce.SRM-Ping'}->{attribute}->{PROXY_PATH} = "-x";
$WLCG_SERVICE->{SRM}->{metrics}->{'hr.srce.SRM-Ping'}->{attribute}->{VONAME} = "-v";

$WLCG_SERVICE->{SRM}->{metrics}->{'hr.srce.SRM-Transfer'}->{config} = {%{$SERVICE_TEMPL->{60}}};
$WLCG_SERVICE->{SRM}->{metrics}->{'hr.srce.SRM-Transfer'}->{probe} = 'hr.srce/SRM-probe';
$WLCG_SERVICE->{SRM}->{metrics}->{'hr.srce.SRM-Transfer'}->{dependency} = ["hr.srce.SRM-CertLifetime","hr.srce.SRM-Ping","hr.srce.GridProxy-Valid"];
$WLCG_SERVICE->{SRM}->{metrics}->{'hr.srce.SRM-Transfer'}->{attribute}->{SE_PATH} = "--path";
$WLCG_SERVICE->{SRM}->{metrics}->{'hr.srce.SRM-Transfer'}->{attribute}->{PROXY_PATH} = "-x";
$WLCG_SERVICE->{SRM}->{metrics}->{'hr.srce.SRM-Transfer'}->{attribute}->{VONAME} = "-v";

$WLCG_SERVICE->{SRM}->{metrics}->{'hr.srce.SRM-CertLifetime'}->{config} = {%{$SERVICE_TEMPL->{1440}}};
$WLCG_SERVICE->{SRM}->{metrics}->{'hr.srce.SRM-CertLifetime'}->{probe} = 'hr.srce/SRM-probe';

# DPNS
$WLCG_SERVICE->{DPNS}->{metrics}->{'hr.srce.DPNS-List'}->{config} = {%{$SERVICE_TEMPL->{15}}};
$WLCG_SERVICE->{DPNS}->{metrics}->{'hr.srce.DPNS-List'}->{probe} = 'hr.srce/DPNS-probe';
$WLCG_SERVICE->{DPNS}->{metrics}->{'hr.srce.DPNS-List'}->{dependency} = ["hr.srce.GridProxy-Valid"];
$WLCG_SERVICE->{DPNS}->{metrics}->{'hr.srce.DPNS-List'}->{attribute}->{PROXY_PATH} = "-x";
$WLCG_SERVICE->{DPNS}->{metrics}->{'hr.srce.DPNS-List'}->{attribute}->{VONAME} = "-v";

# Resource Broker
$WLCG_SERVICE->{ResourceBroker}->{metrics}->{'hr.srce.ResourceBroker-RunJob'}->{config}->{interval} = 60;
$WLCG_SERVICE->{ResourceBroker}->{metrics}->{'hr.srce.ResourceBroker-RunJob'}->{config}->{timeout} = 900;
$WLCG_SERVICE->{ResourceBroker}->{metrics}->{'hr.srce.ResourceBroker-RunJob'}->{config}->{retryInterval} = 20;
$WLCG_SERVICE->{ResourceBroker}->{metrics}->{'hr.srce.ResourceBroker-RunJob'}->{probe} = 'hr.srce/ResourceBroker-probe';
$WLCG_SERVICE->{ResourceBroker}->{metrics}->{'hr.srce.ResourceBroker-RunJob'}->{dependency} = ["hr.srce.GridProxy-Valid","hr.srce.GridFTP-Transfer"];
$WLCG_SERVICE->{ResourceBroker}->{metrics}->{'hr.srce.ResourceBroker-RunJob'}->{attribute}->{PROXY_PATH} = "-x";
$WLCG_SERVICE->{ResourceBroker}->{metrics}->{'hr.srce.ResourceBroker-RunJob'}->{attribute}->{VONAME} = "-v";
# bypass voms proxy cert (GGUS #20558)
#$WLCG_SERVICE->{ResourceBroker}->{metrics}->{RunJob}->{gridproxy} = 1;

$WLCG_SERVICE->{ResourceBroker}->{metrics}->{'hr.srce.ResourceBroker-CertLifetime'}->{config} = {%{$SERVICE_TEMPL->{1440}}};
$WLCG_SERVICE->{ResourceBroker}->{metrics}->{'hr.srce.ResourceBroker-CertLifetime'}->{probe} = 'hr.srce/ResourceBroker-probe';

# LFC
$WLCG_SERVICE->{'glite-LFC'}->{metrics}->{'ch.cern.LFC-Read'}->{config} = {%{$SERVICE_TEMPL->{15}}};
$WLCG_SERVICE->{'glite-LFC'}->{metrics}->{'ch.cern.LFC-Read'}->{probe} = 'ch.cern/LFC-probe';
$WLCG_SERVICE->{'glite-LFC'}->{metrics}->{'ch.cern.LFC-Read'}->{dependency} = ["hr.srce.GridProxy-Valid"];
$WLCG_SERVICE->{'glite-LFC'}->{metrics}->{'ch.cern.LFC-Read'}->{attribute}->{PROXY_PATH} = "";
$WLCG_SERVICE->{'glite-LFC'}->{metrics}->{'ch.cern.LFC-Read'}->{attribute}->{VONAME} = "-v";

$WLCG_SERVICE->{'glite-LFC'}->{metrics}->{'ch.cern.LFC-Write'}->{config} = {%{$SERVICE_TEMPL->{15}}};
$WLCG_SERVICE->{'glite-LFC'}->{metrics}->{'ch.cern.LFC-Write'}->{probe} = 'ch.cern/LFC-probe';
$WLCG_SERVICE->{'glite-LFC'}->{metrics}->{'ch.cern.LFC-Write'}->{dependency} = ["hr.srce.GridProxy-Valid"];
$WLCG_SERVICE->{'glite-LFC'}->{metrics}->{'ch.cern.LFC-Write'}->{attribute}->{PROXY_PATH} = "";
$WLCG_SERVICE->{'glite-LFC'}->{metrics}->{'ch.cern.LFC-Write'}->{attribute}->{VONAME} = "-v";

$WLCG_SERVICE->{'glite-LFC'}->{metrics}->{'ch.cern.LFC-Readdir'}->{config} = {%{$SERVICE_TEMPL->{15}}};
$WLCG_SERVICE->{'glite-LFC'}->{metrics}->{'ch.cern.LFC-Readdir'}->{probe} = 'ch.cern/LFC-probe';
$WLCG_SERVICE->{'glite-LFC'}->{metrics}->{'ch.cern.LFC-Readdir'}->{dependency} = ["hr.srce.GridProxy-Valid"];
$WLCG_SERVICE->{'glite-LFC'}->{metrics}->{'ch.cern.LFC-Readdir'}->{attribute}->{PROXY_PATH} = "";
$WLCG_SERVICE->{'glite-LFC'}->{metrics}->{'ch.cern.LFC-Readdir'}->{attribute}->{VONAME} = "-v";

$WLCG_SERVICE->{'glite-LFC'}->{metrics}->{'ch.cern.LFC-ReadDli'}->{config} = {%{$SERVICE_TEMPL->{15}}};
$WLCG_SERVICE->{'glite-LFC'}->{metrics}->{'ch.cern.LFC-ReadDli'}->{probe} = 'ch.cern/LFC-probe';
$WLCG_SERVICE->{'glite-LFC'}->{metrics}->{'ch.cern.LFC-ReadDli'}->{dependency} = ["hr.srce.GridProxy-Valid"];
$WLCG_SERVICE->{'glite-LFC'}->{metrics}->{'ch.cern.LFC-ReadDli'}->{attribute}->{PROXY_PATH} = "";
$WLCG_SERVICE->{'glite-LFC'}->{metrics}->{'ch.cern.LFC-ReadDli'}->{attribute}->{VONAME} = "-v";

# Resource Broker
$WLCG_SERVICE->{'org.glite.wms.NetworkServer'}->{metrics}->{'hr.srce.WMS-RunJob'}->{config}->{interval} = 60;
$WLCG_SERVICE->{'org.glite.wms.NetworkServer'}->{metrics}->{'hr.srce.WMS-RunJob'}->{config}->{timeout} = 900;
$WLCG_SERVICE->{'org.glite.wms.NetworkServer'}->{metrics}->{'hr.srce.WMS-RunJob'}->{config}->{retryInterval} = 20;
$WLCG_SERVICE->{'org.glite.wms.NetworkServer'}->{metrics}->{'hr.srce.WMS-RunJob'}->{probe} = 'hr.srce/WMS-probe';
$WLCG_SERVICE->{'org.glite.wms.NetworkServer'}->{metrics}->{'hr.srce.WMS-RunJob'}->{dependency} = ["hr.srce.GridProxy-Valid","hr.srce.GridFTP-Transfer"];
$WLCG_SERVICE->{'org.glite.wms.NetworkServer'}->{metrics}->{'hr.srce.WMS-RunJob'}->{attribute}->{PROXY_PATH} = "-x";
$WLCG_SERVICE->{'org.glite.wms.NetworkServer'}->{metrics}->{'hr.srce.WMS-RunJob'}->{attribute}->{VONAME} = "-v";
# bypass voms proxy cert (GGUS #20558)
#$WLCG_SERVICE->{ResourceBroker}->{metrics}->{RunJob}->{gridproxy} = 1;

$WLCG_SERVICE->{'org.glite.wms.NetworkServer'}->{metrics}->{'hr.srce.WMS-CertLifetime'}->{config} = {%{$SERVICE_TEMPL->{1440}}};
$WLCG_SERVICE->{'org.glite.wms.NetworkServer'}->{metrics}->{'hr.srce.WMS-CertLifetime'}->{probe} = 'hr.srce/WMS-probe';

# org.glite.wms.WMProxy
$WLCG_SERVICE->{'org.glite.wms.WMProxy'}->{metrics}->{'hr.srce.WMProxy-RunJob'}->{config}->{interval} = 60;
$WLCG_SERVICE->{'org.glite.wms.WMProxy'}->{metrics}->{'hr.srce.WMProxy-RunJob'}->{config}->{timeout} = 900;
$WLCG_SERVICE->{'org.glite.wms.WMProxy'}->{metrics}->{'hr.srce.WMProxy-RunJob'}->{config}->{retryInterval} = 20;
$WLCG_SERVICE->{'org.glite.wms.WMProxy'}->{metrics}->{'hr.srce.WMProxy-RunJob'}->{probe} = 'hr.srce/WMProxy-probe';
$WLCG_SERVICE->{'org.glite.wms.WMProxy'}->{metrics}->{'hr.srce.WMProxy-RunJob'}->{dependency} = ["hr.srce.GridProxy-Valid","hr.srce.GridFTP-Transfer"];
$WLCG_SERVICE->{'org.glite.wms.WMProxy'}->{metrics}->{'hr.srce.WMProxy-RunJob'}->{attribute}->{PROXY_PATH} = "-x";
$WLCG_SERVICE->{'org.glite.wms.WMProxy'}->{metrics}->{'hr.srce.WMProxy-RunJob'}->{attribute}->{VONAME} = "-v";

$WLCG_SERVICE->{'org.glite.wms.WMProxy'}->{metrics}->{'hr.srce.WMProxy-CertLifetime'}->{config} = {%{$SERVICE_TEMPL->{1440}}};
$WLCG_SERVICE->{'org.glite.wms.WMProxy'}->{metrics}->{'hr.srce.WMProxy-CertLifetime'}->{probe} = 'hr.srce/WMProxy-probe';


$WLCG_SERVICE->{CAdistribution}->{metrics}->{'hr.srce.CAdist-Version'}->{config} = {%{$SERVICE_TEMPL->{1440}}};
$WLCG_SERVICE->{CAdistribution}->{metrics}->{'hr.srce.CAdist-Version'}->{probe} = 'hr.srce/CAdist-probe';
$WLCG_SERVICE->{CAdistribution}->{metrics}->{'hr.srce.CAdist-Version'}->{dependency} = ["hr.srce.GridProxy-Valid"];

# Native services

# Main difference is that we don't know anything about parameters, so all of them
# need to define in attribute hash

# GridFTP-Ping
$WLCG_SERVICE->{gsiftp}->{metrics}->{'org.nagios.GridFTP-Check'}->{native} = 1;
$WLCG_SERVICE->{gsiftp}->{metrics}->{'org.nagios.GridFTP-Check'}->{probe} = "check_ftp";
$WLCG_SERVICE->{gsiftp}->{metrics}->{'org.nagios.GridFTP-Check'}->{config} = {%{$SERVICE_TEMPL->{15}}};
$WLCG_SERVICE->{gsiftp}->{metrics}->{'org.nagios.GridFTP-Check'}->{config}->{timeout} = 60;
$WLCG_SERVICE->{gsiftp}->{metrics}->{'org.nagios.GridFTP-Check'}->{attribute}->{GRIDFTP_PORT} = "-p";

# BDII
$WLCG_SERVICE->{BDII}->{metrics}->{'org.nagios.BDII-Check'}->{native} = 1;
$WLCG_SERVICE->{BDII}->{metrics}->{'org.nagios.BDII-Check'}->{probe} = "check_ldap";
$WLCG_SERVICE->{BDII}->{metrics}->{'org.nagios.BDII-Check'}->{config} = {%{$SERVICE_TEMPL->{15}}};
$WLCG_SERVICE->{BDII}->{metrics}->{'org.nagios.BDII-Check'}->{config}->{timeout} = 60;
$WLCG_SERVICE->{BDII}->{metrics}->{'org.nagios.BDII-Check'}->{attribute}->{BDII_DN} = "-b";
$WLCG_SERVICE->{BDII}->{metrics}->{'org.nagios.BDII-Check'}->{attribute}->{BDII_PORT} = "-p";

# MDS-GIIS
$WLCG_SERVICE->{'MDS-GIIS'}->{metrics}->{'org.nagios.MDS-Check'}->{native} = 1;
$WLCG_SERVICE->{'MDS-GIIS'}->{metrics}->{'org.nagios.MDS-Check'}->{probe} = "check_ldap";
$WLCG_SERVICE->{'MDS-GIIS'}->{metrics}->{'org.nagios.MDS-Check'}->{config} = {%{$SERVICE_TEMPL->{15}}};
$WLCG_SERVICE->{'MDS-GIIS'}->{metrics}->{'org.nagios.MDS-Check'}->{config}->{timeout} = 60;
$WLCG_SERVICE->{'MDS-GIIS'}->{metrics}->{'org.nagios.MDS-Check'}->{attribute}->{MDS_DN} = "-b";
$WLCG_SERVICE->{'MDS-GIIS'}->{metrics}->{'org.nagios.MDS-Check'}->{attribute}->{MDS_PORT} = "-p";

# it.infn.GridICE
$WLCG_SERVICE->{'it.infn.GridICE'}->{metrics}->{'org.nagios.GridICE-Check'}->{native} = 1;
$WLCG_SERVICE->{'it.infn.GridICE'}->{metrics}->{'org.nagios.GridICE-Check'}->{probe} = "check_ldap";
$WLCG_SERVICE->{'it.infn.GridICE'}->{metrics}->{'org.nagios.GridICE-Check'}->{config} = {%{$SERVICE_TEMPL->{15}}};
$WLCG_SERVICE->{'it.infn.GridICE'}->{metrics}->{'org.nagios.GridICE-Check'}->{config}->{timeout} = 60;
$WLCG_SERVICE->{'it.infn.GridICE'}->{metrics}->{'org.nagios.GridICE-Check'}->{attribute}->{GRIDICE_DN} = "-b";
$WLCG_SERVICE->{'it.infn.GridICE'}->{metrics}->{'org.nagios.GridICE-Check'}->{attribute}->{GRIDICE_PORT} = "-p";


1;
